==> yoofans-wechat-service-api-1.0.2.sunyan-20180203.073048-5-sources.jar: cn/yoofans/wechat/api/dto/miniapp/MpMsgTemplatePushDto.java <==
package cn.yoofans.wechat.api.dto.miniapp;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by sunyan on 2018/2/1.
 */
public class MpMsgTemplatePushDto implements Serializable {

    private static final long serialVersionUID = 8233813961988813453L;
    private Long id;

    private String appId;

    private Long odpsId;

    private Integer eventType;

    private Date triggerDate;

    private String templateId;

    private String page;

    private String emphasisKeyword;

    private Long pushNum;

    private Integer pushStatus;

    private Date pushTime;

    private String search;

    private Integer deleted;

    private Date gmtCreate;

    private Date gmtModified;

    private List<MpPushKeyDto> mpPushKeyList;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public Long getOdpsId() {
        return odpsId;
    }

    public void setOdpsId(Long odpsId) {
        this.odpsId = odpsId;
    }

    public Integer getEventType() {
        return eventType;
    }

    public void setEventType(Integer eventType) {
        this.eventType = eventType;
    }

    public Date getTriggerDate() {
        return triggerDate;
    }

    public void setTriggerDate(Date triggerDate) {
        this.triggerDate = triggerDate;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public String getPage() {
        return page;
    }

    public void setPage(String page) {
        this.page = page;
    }

    public String getEmphasisKeyword() {
        return emphasisKeyword;
    }

    public void setEmphasisKeyword(String emphasisKeyword) {
        this.emphasisKeyword = emphasisKeyword;
    }

    public Long getPushNum() {
        return pushNum;
    }

    public void setPushNum(Long pushNum) {
        this.pushNum = pushNum;
    }

    public Integer getPushStatus() {
        return pushStatus;
    }

    public void setPushStatus(Integer pushStatus) {
        this.pushStatus = pushStatus;
    }

    public Date getPushTime() {
        return pushTime;
    }

    public void setPushTime(Date pushTime) {
        this.pushTime = pushTime;
    }

    public String getSearch() {
        return search;
    }

    public void setSearch(String search) {
        this.search = search;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public List<MpPushKeyDto> getMpPushKeyList() {
        return mpPushKeyList;
    }

    public void setMpPushKeyList(List<MpPushKeyDto> mpPushKeyList) {
        this.mpPushKeyList = mpPushKeyList;
    }
}

==> yoofans-wechat-service-api-1.0.5.sunyan-20180224.091255-10-sources.jar: cn/yoofans/wechat/api/dto/miniapp/MpMsgTemplatePushDto.java <==
package cn.yoofans.wechat.api.dto.miniapp;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by sunyan on 2018/2/1.
 */
public class MpMsgTemplatePushDto implements Serializable {

    private static final long serialVersionUID = 8233813961988813453L;
    private Long id;

    private String appId;

    private Long odpsId;

    private Integer eventType;

    private Date triggerDate;

    private String templateId;

    private String jumpPage;

    private String emphasisKeyword;

    private Long pushNum;

    private Integer pushStatus;

    private Date pushTime;

    private String search;

    private Integer deleted;

    private Date gmtCreate;

    private Date gmtModified;

    private Boolean pushNow;

    private String title;

    private List<MpPushKeyDto> mpPushKeyList;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public Long getOdpsId() {
        return odpsId;
    }

    public void setOdpsId(Long odpsId) {
        this.odpsId = odpsId;
    }

    public Integer getEventType() {
        return eventType;
    }

    public void setEventType(Integer eventType) {
        this.eventType = eventType;
    }

    public Date getTriggerDate() {
        return triggerDate;
    }

    public void setTriggerDate(Date triggerDate) {
        this.triggerDate = triggerDate;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public String getJumpPage() {
        return jumpPage;
    }

    public void setJumpPage(String jumpPage) {
        this.jumpPage = jumpPage;
    }

    public String getEmphasisKeyword() {
        return emphasisKeyword;
    }

    public void setEmphasisKeyword(String emphasisKeyword) {
        this.emphasisKeyword = emphasisKeyword;
    }

    public Long getPushNum() {
        return pushNum;
    }

    public void setPushNum(Long pushNum) {
        this.pushNum = pushNum;
    }

    public Integer getPushStatus() {
        return pushStatus;
    }

    public void setPushStatus(Integer pushStatus) {
        this.pushStatus = pushStatus;
    }

    public Date getPushTime() {
        return pushTime;
    }

    public void setPushTime(Date pushTime) {
        this.pushTime = pushTime;
    }

    public String getSearch() {
        return search;
    }

    public void setSearch(String search) {
        this.search = search;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Boolean getPushNow() {
        return pushNow;
    }

    public void setPushNow(Boolean pushNow) {
        this.pushNow = pushNow;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<MpPushKeyDto> getMpPushKeyList() {
        return mpPushKeyList;
    }

    public void setMpPushKeyList(List<MpPushKeyDto> mpPushKeyList) {
        this.mpPushKeyList = mpPushKeyList;
    }
}
